==> 1.2.0+2022.11.3.zip: authentik/README.md <==
# authentik

[authentik](https://goauthentik.io/) is an open-source Identity Provider focused on flexibility and versatility


[List of all possible environment variables](https://goauthentik.io/docs/installation/configuration)

<!-- metadata -->

* **Category**: Apps
* **Status**: 0, work-in-progress
* **Image**: [ghcr/goauthentik/server](https://ghcr.io/goauthentik/server)
* **Healthcheck**: Yes
* **Backups**: Yes
* **Email**: Yes
* **Tests**: No
* **SSO**: Yes

<!-- endmetadata -->

## Quick start

* `abra app new authentik`
* `abra app config <app-name>`
* `abra app secret insert <app_name> email_pass v1 <password>`
* `abra app secret generate -a <app_name>
* `abra app deploy <app-name>`
* `abra app cmd <app_name> app set_admin_pass`

## Rotate Secrets

```
abra app secret generate -a <app_name>
abra app undeploy <app_name>
abra app deploy <app_name>
abra app cmd <app_name> db rotate_db_pass
abra app cmd <app_name> app set_admin_pass
```

## Customization

Place the files you want to overwrite in a directory `<assets_path>`.
Run `abra app config <app_name>` and define the env variable `COPY_ASSETS` in the following format:

```
"<source_file1>|<service>:<target_directory1> <source_file2>|<service>:<target_directory2> ...
```

For example:

```
COPY_ASSETS="flow_background.jpg|app:/web/dist/assets/images/ icon_left_brand.svg|app:/web/dist/assets/icons/ icon.png|app:/web/dist/assets/icons/"
```

Run this command after every deploy/upgrade:

`abra app command --local <app-name> customize <assets_path>`

For more, see [`docs.coopcloud.tech`](https://docs.coopcloud.tech).

==> 1.3.0+2022.12.2.zip: authentik/README.md <==
# authentik

[authentik](https://goauthentik.io/) is an open-source Identity Provider focused on flexibility and versatility


[List of all possible environment variables](https://goauthentik.io/docs/installation/configuration)

<!-- metadata -->

* **Category**: Apps
* **Status**: 0, work-in-progress
* **Image**: [ghcr/goauthentik/server](https://ghcr.io/goauthentik/server), 4, upstream
* **Healthcheck**: Yes
* **Backups**: Yes
* **Email**: Yes
* **Tests**: No
* **SSO**: Yes

<!-- endmetadata -->

## Quick start

* `abra app new authentik`
* `abra app config <app-name>`
* `abra app secret insert <app_name> email_pass v1 <password>`
* `abra app secret generate -a <app_name>`
* `abra app deploy <app-name>`
* `abra app cmd <app_name> app set_admin_pass`

## Rotate Secrets

Increment the secret versions using `abra app config <app_name>`

```
abra app secret generate -a <app_name>
abra app undeploy <app_name>
abra app deploy <app_name>
abra app cmd <app_name> db rotate_db_pass
abra app cmd <app_name> app set_admin_pass
```

## Customization

Place the files you want to overwrite in a directory `<assets_path>`.
Run `abra app config <app_name>` and define the env variable `COPY_ASSETS` in the following format:

```
"<source_file1>|<service>:<target_directory1> <source_file2>|<service>:<target_directory2> ...
```

For example:

```
COPY_ASSETS="flow_background.jpg|app:/web/dist/assets/images/ icon_left_brand.svg|app:/web/dist/assets/icons/ icon.png|app:/web/dist/assets/icons/"
```

Run this command after every deploy/upgrade:

`abra app command --local <app-name> customize <assets_path>`

For more, see [`docs.coopcloud.tech`](https://docs.coopcloud.tech).
